@@ -3,7 +3,7 @@ BEGIN {
   $POE::Component::IRC::Plugin::Console::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Plugin::Console::VERSION = '6.49';
+  $POE::Component::IRC::Plugin::Console::VERSION = '6.50';
 }
 
 use strict;
@@ -11,6 +11,7 @@ use warnings FATAL => 'all';
 use Carp;
 use POE qw(Wheel::SocketFactory Wheel::ReadWrite Filter::IRCD Filter::Line Filter::Stackable);
 use POE::Component::IRC::Plugin qw( :ALL );
+use Scalar::Util qw(looks_like_number);
 
 sub new {
     my $package = shift;
@@ -45,6 +46,34 @@ sub PCI_unregister {
     return 1;
 }
 
+sub _dump {
+    my ($arg) = @_;
+
+    if (ref $arg eq 'ARRAY') {
+        my @elems;
+        for my $elem (@$arg) {
+            push @elems, _dump($elem);
+        }
+        return '['. join(', ', @elems) .']';
+    }
+    elsif (ref $arg eq 'HASH') {
+        my @pairs;
+        for my $key (keys %$arg) {
+            push @pairs, [$key, _dump($arg->{$key})];
+        }
+        return '{'. join(', ', map { "$_->[0] => $_->[1]" } @pairs) .'}';
+    }
+    elsif (ref $arg) {
+        return $arg;
+    }
+    elsif (defined $arg) {
+        return looks_like_number($arg) ? $arg : "'$arg'";
+    }
+    else {
+        return 'undef';
+    }
+}
+
 sub _default {
     my ($self, $irc, $event) = splice @_, 0, 3;
     return PCI_EAT_NONE if $event eq 'S_raw';
@@ -53,19 +82,8 @@ sub _default {
     my @args = map { $$_ } @_;
     my @output;
 
-    for my $arg (@args) {
-        if (ref $arg eq 'ARRAY') {
-            push @output, '['. join(', ', map { "'$_'" } @$arg) .']';
-        }
-        elsif (ref $arg eq 'HASH') {
-            push @output, '{'. join(', ', map { "$_ => '$arg->{$_}'" } keys %$arg) .'}';
-        }
-        elsif (defined $arg) {
-            push @output, "'$arg'";
-        }
-        else {
-            push @output, 'undef';
-        }
+    for my $i (0..$#args) {
+        push @output, "ARG$i: " . _dump($args[$i]);
     }
 
     for my $wheel_id ( keys %{ $self->{wheels} } ) {
